/*************************************************************************
 * ArtisticStylePlugin: Using Artistic Style at Qt Creator.              *
 * Copyright (C) 2010-2011  Lorenz Haas <lykurg@gmail.com>               *
 *                                                                       *
 * This program is free software: you can redistribute it and/or modify  *
 * it under the terms of the GNU General Public License as published by  *
 * the Free Software Foundation, either version 3 of the License, or     *
 * (at your option) any later version.                                   *
 *                                                                       *
 * This program is distributed in the hope that it will be useful,       *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 * GNU General Public License for more details.                          *
 *                                                                       *
 * You should have received a copy of the GNU General Public License     *
 * along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 *************************************************************************/

#include "artisticstyleiterator.h"

#include <QTextStream>

namespace ArtisticStyle
{
  namespace Internal
  {
    ArtisticStyleIterator::ArtisticStyleIterator(QTextStream* stream) : m_stream(stream)
    {
      m_stream->reset();
      m_prevLineDeleted = false;
      checkForEmptyLine = false;
      m_peekStart = 0;
    }

    ArtisticStyleIterator::~ArtisticStyleIterator() {}

    const char* ArtisticStyleIterator::getOutputEOL() const
    {
      return "\n";
    }

    bool ArtisticStyleIterator::compareToInputBuffer(const std::string& nextLine) const
    {
      return (nextLine == m_prevBuffer.toLocal8Bit().data());
    }

    bool ArtisticStyleIterator::hasMoreLines() const
    {
      return !m_stream->atEnd();
    }

    std::string ArtisticStyleIterator::nextLine(bool emptyLineWasDeleted)
    {
      if (m_prevLineDeleted)
      {
        m_prevLineDeleted = false;
        checkForEmptyLine = true;
      }
      if (!emptyLineWasDeleted)
        m_prevBuffer = m_buffer;
      else
        m_prevLineDeleted = true;
      m_buffer = m_stream->readLine();
      return m_buffer.toLocal8Bit().data();
    }

    std::string ArtisticStyleIterator::peekNextLine()
    {
      if (m_peekStart == 0)
        m_peekStart = m_stream->pos();
      return m_stream->readLine().toLocal8Bit().data();
    }

    void ArtisticStyleIterator::peekReset()
    {
      m_stream->seek(m_peekStart);
      m_peekStart = 0;
    }

    bool ArtisticStyleIterator::getLineEndChange(int /*lineEndFormat*/) const
    {
      return false;
    }

    void ArtisticStyleIterator::saveLastInputLine()
    {
      m_prevBuffer = m_buffer;
    }
  } // namespace Internal
} // namespace ArtisticStyle
