/*************************************************************************
 * ArtisticStylePlugin: Using Artistic Style at Qt Creator.              *
 * Copyright (C) 2010-2011  Lorenz Haas <lykurg@gmail.com>               *
 *                                                                       *
 * This program is free software: you can redistribute it and/or modify  *
 * it under the terms of the GNU General Public License as published by  *
 * the Free Software Foundation, either version 3 of the License, or     *
 * (at your option) any later version.                                   *
 *                                                                       *
 * This program is distributed in the hope that it will be useful,       *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 * GNU General Public License for more details.                          *
 *                                                                       *
 * You should have received a copy of the GNU General Public License     *
 * along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 *************************************************************************/

#include "artisticstyleoptionpage.h"
#include "artisticstyleoptionpagegui.h"

#if (IDE_VERSION_MAJOR == 2)
static const char* astyle_categoryIcon[] =
{
  "64 64 194 2",
  "  	c None",
  ". 	c #9D9D9D",
  "+ 	c #979797",
  "@ 	c #969696",
  "# 	c #9E9E9E",
  "$ 	c #CBCBCB",
  "% 	c #FAFAFA",
  "& 	c #FDFDFD",
  "* 	c #CACACA",
  "= 	c #F8F8F8",
  "- 	c #FCFCFC",
  "; 	c #FBFBFB",
  "> 	c #D8D8D8",
  ", 	c #000000",
  "' 	c #1E1E1E",
  ") 	c #F9F9F9",
  "! 	c #7B7B7B",
  "~ 	c #BABABA",
  "{ 	c #F7F7F7",
  "] 	c #212121",
  "^ 	c #616161",
  "/ 	c #FFFFFF",
  "( 	c #FEFEFE",
  "_ 	c #BDBDBD",
  ": 	c #0E0E0E",
  "< 	c #F6F6F6",
  "[ 	c #A6A6A6",
  "} 	c #F5F5F5",
  "| 	c #EDEDED",
  "1 	c #0F0F0F",
  "2 	c #484848",
  "3 	c #F4F4F4",
  "4 	c #A3A3A3",
  "5 	c #030303",
  "6 	c #E7E7E7",
  "7 	c #F3F3F3",
  "8 	c #8D8D8D",
  "9 	c #F2F2F2",
  "0 	c #DEDEDE",
  "a 	c #040404",
  "b 	c #3E3E3E",
  "c 	c #2F2F2F",
  "d 	c #F1F1F1",
  "e 	c #888888",
  "f 	c #161616",
  "g 	c #D4D4D4",
  "h 	c #D2D2D2",
  "i 	c #303030",
  "j 	c #696969",
  "k 	c #747474",
  "l 	c #F0F0F0",
  "m 	c #C8C8C8",
  "n 	c #C1C1C1",
  "o 	c #878787",
  "p 	c #1A1A1A",
  "q 	c #EFEFEF",
  "r 	c #707070",
  "s 	c #1B1B1B",
  "t 	c #DDDDDD",
  "u 	c #B8B8B8",
  "v 	c #EEEEEE",
  "w 	c #ECECEC",
  "x 	c #717171",
  "y 	c #323232",
  "z 	c #5A5A5A",
  "A 	c #AFAFAF",
  "B 	c #C9C9C9",
  "C 	c #828282",
  "D 	c #0A0A0A",
  "E 	c #575757",
  "F 	c #010101",
  "G 	c #9F9F9F",
  "H 	c #EBEBEB",
  "I 	c #E1E1E1",
  "J 	c #0B0B0B",
  "K 	c #787878",
  "L 	c #363636",
  "M 	c #414141",
  "N 	c #EAEAEA",
  "O 	c #D0D0D0",
  "P 	c #868686",
  "Q 	c #E2E2E2",
  "R 	c #E9E9E9",
  "S 	c #3F3F3F",
  "T 	c #292929",
  "U 	c #D3D3D3",
  "V 	c #020202",
  "W 	c #D1D1D1",
  "X 	c #808080",
  "Y 	c #3B3B3B",
  "Z 	c #E8E8E8",
  "` 	c #7E7E7E",
  " .	c #8A8A8A",
  "..	c #D5D5D5",
  "+.	c #6D6D6D",
  "@.	c #E6E6E6",
  "#.	c #151515",
  "$.	c #E5E5E5",
  "%.	c #656565",
  "&.	c #B1B1B1",
  "*.	c #E4E4E4",
  "=.	c #545454",
  "-.	c #E3E3E3",
  ";.	c #A1A1A1",
  ">.	c #070707",
  ",.	c #4D4D4D",
  "'.	c #989898",
  ").	c #080808",
  "!.	c #3A3A3A",
  "~.	c #DCDCDC",
  "{.	c #E0E0E0",
  "].	c #B0B0B0",
  "^.	c #7F7F7F",
  "/.	c #DFDFDF",
  "(.	c #C3C3C3",
  "_.	c #454545",
  ":.	c #0D0D0D",
  "<.	c #222222",
  "[.	c #727272",
  "}.	c #9C9C9C",
  "|.	c #505050",
  "1.	c #C4C4C4",
  "2.	c #050505",
  "3.	c #9B9B9B",
  "4.	c #666666",
  "5.	c #ACACAC",
  "6.	c #4A4A4A",
  "7.	c #D7D7D7",
  "8.	c #101010",
  "9.	c #DBDBDB",
  "0.	c #5B5B5B",
  "a.	c #A0A0A0",
  "b.	c #525252",
  "c.	c #AAAAAA",
  "d.	c #DADADA",
  "e.	c #D9D9D9",
  "f.	c #D6D6D6",
  "g.	c #242424",
  "h.	c #AEAEAE",
  "i.	c #B3B3B3",
  "j.	c #606060",
  "k.	c #ADADAD",
  "l.	c #8B8B8B",
  "m.	c #646464",
  "n.	c #393939",
  "o.	c #4F4F4F",
  "p.	c #474747",
  "q.	c #515151",
  "r.	c #C7C7C7",
  "s.	c #2B2B2B",
  "t.	c #ABABAB",
  "u.	c #C2C2C2",
  "v.	c #737373",
  "w.	c #CECECE",
  "x.	c #060606",
  "y.	c #4E4E4E",
  "z.	c #262626",
  "A.	c #939393",
  "B.	c #232323",
  "C.	c #0C0C0C",
  "D.	c #131313",
  "E.	c #BFBFBF",
  "F.	c #383838",
  "G.	c #6B6B6B",
  "H.	c #7D7D7D",
  "I.	c #313131",
  "J.	c #5F5F5F",
  "K.	c #898989",
  "L.	c #191919",
  "M.	c #424242",
  "N.	c #5E5E5E",
  "O.	c #A9A9A9",
  "P.	c #2D2D2D",
  "Q.	c #858585",
  "R.	c #B2B2B2",
  "S.	c #141414",
  "T.	c #999999",
  "U.	c #CFCFCF",
  "V.	c #A8A8A8",
  "W.	c #A2A2A2",
  "X.	c #202020",
  "Y.	c #2A2A2A",
  "Z.	c #404040",
  "`.	c #464646",
  " +	c #5D5D5D",
  ".+	c #353535",
  "++	c #CDCDCD",
  "@+	c #8F8F8F",
  "#+	c #BCBCBC",
  "$+	c #CCCCCC",
  "%+	c #777777",
  "&+	c #121212",
  "*+	c #1F1F1F",
  "=+	c #9A9A9A",
  "                                                                                                                                ",
  "    . + @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ + .     ",
  "  # $ % & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & & % * #   ",
  "  + = - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - = +   ",
  "  @ ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; @   ",
  "  @ % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % @   ",
  "  @ % % % % % % % % % % % % % % % % % % % % % % > , , , , , , , , , , ' ) % % % % % % % % % % % % % % % % % % % % % % % % % @   ",
  "  @ = = = = = = = = = = = = = = = = = = = = = = ! , , , , , , , , , , , ~ = = = = = = = = = = = = = = = = = = = = = = = = = @   ",
  "  @ = = = = = = = = = = = = = = = = = = = = = { ] , , , , , , , , , , , ^ / ( = = = = = = = = = = = = = = = = = = = = = = = @   ",
  "  @ { { { { { { { { { { { { { { { { { { { { { _ , , , , , , , , , , , , : < / ) { { { { { { { { { { { { { { { { { { { { { { @   ",
  "  @ < < < < < < < < < < < < < < < < < < < < < ^ , , , , , , , , , , , , , [ / - < < < < < < < < < < < < < < < < < < < < < < @   ",
  "  @ } } } } } } } } } } } } } } } } } } } } | 1 , , , , , , , , , , , , , 2 / ( } } } } } } } } } } } } } } } } } } } } } } @   ",
  "  @ 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 4 , , , , , , , , , , , , , , 5 6 / = 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 @   ",
  "  @ 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 2 , , , , , , , , , , , , , , , 8 / - 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 @   ",
  "  @ 9 9 9 9 9 9 9 9 9 9 9 9 9 9 9 9 9 9 9 0 a , , , , , , , b , , , , , , , c / / 7 9 9 9 9 9 9 9 9 9 9 9 9 9 9 9 9 9 9 9 9 @   ",
  "  @ d d d d d d d d d d d d d d d d d d d e , , , , , , , f g , , , , , , , , h / { d d d d d d d d d d d d d d d d d d d d @   ",
  "  @ d d d d d d d d d d d d d d d d d d d i , , , , , , , j / c , , , , , , , k / - d d d d d d d d d d d d d d d d d d d d @   ",
  "  @ l l l l l l l l l l l l l l l l l l m , , , , , , , , n / o , , , , , , , p - / 7 l l l l l l l l l l l l l l l l l l l @   ",
  "  @ q q q q q q q q q q q q q q q q q q r , , , , , , , s ( / t , , , , , , , , u / = q q q q q q q q q q q q q q q q q q q @   ",
  "  @ v v v v v v v v v v v v v v v v v w p , , , , , , , x / / / y , , , , , , , z / & v v v v v v v v v v v v v v v v v v v @   ",
  "  @ | | | | | | | | | | | | | | | | | A , , , , , , , , B / / & C , , , , , , , D 7 / 9 | | | | | | | | | | | | | | | | | | @   ",
  "  @ w w w w w w w w w w w w w w w w w E , , , , , , , ] / / / { h F , , , , , , , G / = w w w w w w w w w w w w w w w w w w @   ",
  "  @ H H H H H H H H H H H H H H H H I J , , , , , , , K / / / q H L , , , , , , , M / ( w H H H H H H H H H H H H H H H H H @   ",
  "  @ N N N N N N N N N N N N N N N N @ , , , , , , , , O / / - N N P , , , , , , , F Q / 9 N N N N N N N N N N N N N N N N N @   ",
  "  @ R R R R R R R R R R R R R R R R S , , , , , , , T / / / } R R U V , , , , , , , P / ) R R R R R R R R R R R R R R R R R @   ",
  "  @ R R R R R R R R R R R R R R R W V , , , , , , , X / / / | R R R Y , , , , , , , T / / w R R R R R R R R R R R R R R R R @   ",
  "  @ Z Z Z Z Z Z Z Z Z Z Z Z Z Z Z ` , , , , , , , , > / / ; Z Z Z Z  ., , , , , , , , * / 7 Z Z Z Z Z Z Z Z Z Z Z Z Z Z Z Z @   ",
  "  @ 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 T , , , , , , , i / / / 7 6 6 6 6 ..a , , , , , , , +./ ; 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 @   ",
  "  @ @.@.@.@.@.@.@.@.@.@.@.@.@.@.~ , , , , , , , , , , , , , , , , , , , , , , , , , , #.% / H @.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@   ",
  "  @ $.$.$.$.$.$.$.$.$.$.$.$.$.$.%., , , , , , , , , , , , , , , , , , , , , , , , , , , &./ 3 $.$.$.$.$.$.$.$.$.$.$.$.$.$.$.@   ",
  "  @ *.*.*.*.*.*.*.*.*.*.*.*.*.I #., , , , , , , , , , , , , , , , , , , , , , , , , , , =./ & $.*.*.*.*.*.*.*.*.*.*.*.*.*.*.@   ",
  "  @ -.-.-.-.-.-.-.-.-.-.-.-.-.;., , , , , , , , , , , , , , , , , , , , , , , , , , , , >.q / w -.-.-.-.-.-.-.-.-.-.-.-.-.-.@   ",
  "  @ Q Q Q Q Q Q Q Q Q Q Q Q Q ,., , , , , , , , , , , , , , , , , , , , , , , , , , , , , './ } Q Q Q Q Q Q Q Q Q Q Q Q Q Q @   ",
  "  @ I I I I I I I I I I I I ..)., , , , , , , , , , , , , , , , , , , , , , , , , , , , , !./ ( -.I I I I I I I I I I I I I @   ",
  "  @ I I I I I I I I I I I I  ., , , , , , , , =.! ! ! ! ! ! ! ! ! ! ! ! ! L , , , , , , , , ~./ | I I I I I I I I I I I I I @   ",
  "  @ {.{.{.{.{.{.{.{.{.{.{.{.L , , , , , , , 5 N / / / / / / / / / / / / / ]., , , , , , , , ^./ = {.{.{.{.{.{.{.{.{.{.{.{.{.@   ",
  "  @ /././././././././././.(.F , , , , , , , _./ / / 3 l l l l l l l l l l R :., , , , , , , <./ / -././././././././././././.@   ",
  "  @ 0 0 0 0 0 0 0 0 0 0 0 [., , , , , , , , }./ / / I 0 0 0 0 0 0 0 0 0 0 0 |., , , , , , , , 1./ q 0 0 0 0 0 0 0 0 0 0 0 0 @   ",
  "  @ t t t t t t t t t t t ] , , , , , , , 2.| / / < t t t t t t t t t t t t 3., , , , , , , , 4./ % t t t t t t t t t t t t @   ",
  "  @ ~.~.~.~.~.~.~.~.~.~.5., , , , , , , , 6./ / / N ~.~.~.~.~.~.~.~.~.~.~.~.7.: , , , , , , , 8.= / *.~.~.~.~.~.~.~.~.~.~.~.@   ",
  "  @ 9.9.9.9.9.9.9.9.9.9.0., , , , , , , , a./ / ( 0 9.9.9.9.9.9.9.9.9.9.9.9.9.b., , , , , , , , c./ d 9.9.9.9.9.9.9.9.9.9.9.@   ",
  "  @ d.d.d.d.d.d.d.d.d.d.d.d.d.Q / / / / / / / / 3 d.d.d.d.d.d.d.d.d.d.d.d.d.d.d.d.9.& / / / / / / / & 9.d.d.d.d.d.d.d.d.d.d.@   ",
  "  @ d.d.d.d.d.d.d.d.d.d.d.d.d.l / / / / / / / / Z d.d.d.d.d.d.d.d.d.d.d.d.d.d.d.d.d.d / / / / / / / / @.d.d.d.d.d.d.d.d.d.d.@   ",
  "  @ e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.@   ",
  "  @ > > > > > > > > > > > > > > > > > > > > > > > > > > > > > > > > > > > > > > > > > > > > > > > > > > > > > > > > > > > > @   ",
  "  @ 7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.@   ",
  "  @ f.f.f.f.f.f.f.f.f.f.f.f.f.g., , :.,.$ f.p h.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.p h.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.@   ",
  "  @ ..........................g. .h i.] j...p k.................................P 1.........................................@   ",
  "  @ g g g g g g g g g g g g g g.l.g g m.n.g p 5.g V (.g g o.k g g [ <.: p.6.k g p 5.g 8.x c s q.h g g g g g g g g g g g g g @   ",
  "  @ U U U U U U U U U U U U U g. .U r.s.E U p t.U V u.U U o.v.U w.f X U 3.x.v.U p t.U 8.y.W w.z.A.U U U U U U U U U U U U U @   ",
  "  @ h h h h h h h h h h h h h B.C.D.a L E.h p c.h V u.h h y.[.h G s h h h F.[.h p c.h 8.[ h h z G.h h h h h h h h h h h h h @   ",
  "  @ h h h h h h h h h h h h h B.H.E.* h h h p c.h V u.h h y.[.h 8 I.h h h o.[.h p c.h 8.&.h h J.%.h h h h h h h h h h h h h @   ",
  "  @ W W W W W W W W W W W W W B.K.W W W W W L.c.W >._ W W M.[.W # s W W W F.[.W L.c.W 8.].W W N.%.W W W W W W W W W W W W W @   ",
  "  @ O O O O O O O O O O O O O B.e O O O O O L.O.O P.Q.O R.J x O $ S.` O T.x.x O L.O.O 1 A O O N.m.O O O O O O O O O O O O O @   ",
  "  @ U.U.U.U.U.U.U.U.U.U.U.U.U.B.e U.U.U.U.U.L.V.U.W.X.Y._.Z.x U.U.;.X.: M.`.v.U.L.V.U.1 A U.U. +m.U.U.U.U.U.U.U.U.U.U.U.U.U.@   ",
  "  @ w.w.w.w.w.w.w.w.w.w.w.w.w.w.w.w.w.w.w.w.w.w.w.w.w.w.w.w.w.w.w.w.w.w.w..+P w.w.w.w.w.w.w.w.w.w.w.w.w.w.w.w.w.w.w.w.w.w.w.@   ",
  "  @ ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++G E.++@+D #+++++++++++++++++++++++++++++++++++++++++++++++@   ",
  "  @ $+$+$+$+$+$+$+$+$+$+$+$+$+$+$+$+$+$+$+$+$+$+$+$+$+$+$+$+$+$+$+%+&+:.*+@+$+$+$+$+$+$+$+$+$+$+$+$+$+$+$+$+$+$+$+$+$+$+$+$+@   ",
  "  @ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ @   ",
  "  @ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ $ @   ",
  "  @ m * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * m @   ",
  "  =+].r.B B B B B B B B B B B B B B B B B B B B B B B B B B B B B B B B B B B B B B B B B B B B B B B B B B B B B B B B r.A =+  ",
  "    T.@ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ '.    ",
  "                                                                                                                                "
};
#endif

namespace ArtisticStyle
{
  namespace Internal
  {
    ArtisticStyleOptionPage::ArtisticStyleOptionPage(QObject* parent)
      : IOptionsPage(parent), m_gui(0)
    {
    }

    ArtisticStyleOptionPage::~ArtisticStyleOptionPage()
    {
    }

    QString ArtisticStyleOptionPage::id() const
    {
      return "ArtisticStylePluginOptions";
    }

    QString ArtisticStyleOptionPage::trName() const
    {
      return tr("Options");
    }

    QString ArtisticStyleOptionPage::category() const
    {
      return "Artistic Style";
    }

    QString ArtisticStyleOptionPage::trCategory() const
    {
      return tr("Artistic Style");
    }

#if (IDE_VERSION_MAJOR == 2)
    QString ArtisticStyleOptionPage::displayName() const
    {
      return tr("General");
    }

    QString ArtisticStyleOptionPage::displayCategory() const
    {
      return tr("Artistic Style Plugin");
    }

    QIcon ArtisticStyleOptionPage::categoryIcon() const
    {
      return QIcon(astyle_categoryIcon);
    }
#endif

    QWidget* ArtisticStyleOptionPage::createPage(QWidget* parent)
    {
      m_gui = new ArtisticStyleOptionPageGui(parent);
      return m_gui;
    }

    void ArtisticStyleOptionPage::apply()
    {
      if (m_gui)
        if (m_gui->save())
          Q_EMIT preferencesChanged();
    }

    void ArtisticStyleOptionPage::finish()
    {
    }
  } // namespace Internal
} // namespace ArtisticStyle
